package samples.files;

/*
 * A simple application that demonstrates the use of Aspera Java fasp Manager
 * API. Aspera, Inc.
 */

import com.asperasoft.faspmanager.Encryption;
import com.asperasoft.faspmanager.FaspManager;
import com.asperasoft.faspmanager.LocalLocation;
import com.asperasoft.faspmanager.Policy;
import com.asperasoft.faspmanager.RemoteLocation;
import com.asperasoft.faspmanager.Resume;
import com.asperasoft.faspmanager.TransferOrder;
import com.asperasoft.faspmanager.XferParams;

class SimplePersistentDownload {
	public static void main(String[] args) throws Exception {
		try {
			/* If Fasp Manager does not automatically find ascp use this specify the path to ascp */
			// Environment.setFasp2ScpPath("C:\\Program Files (x86)\\Aspera\\Enterprise Server\\bin\\ascp.exe");

			FaspManagerListener faspManagerListener = new FaspManagerListener();
			FaspManager.getSingleton().addListener(faspManagerListener);

			RemoteLocation remoteSourceFiles =
					new RemoteLocation("demo.asperasoft.com", "aspera",
							"demoaspera");

			LocalLocation localDestination = new LocalLocation();
			/* Note that we do not add any paths to the location objects */

			/* Setup a job order. */
			TransferOrder order =
					new TransferOrder(remoteSourceFiles, localDestination,
							myTransferParams());

			/* Submit the job for transfer */
			String jobId = FaspManager.getSingleton().startTransfer(order);

			/* Wait for the session to be started */
			while (!faspManagerListener.isSessionReady())
				Thread.sleep(100);

			/* Queue a file for upload */
			FaspManager.getSingleton().addSource(jobId, "aspera-test-dir-small/10MB.1", "10MB.1");

			/* No more files can be added. The session will end once all current transfers are finished */
			FaspManager.getSingleton().lockPersistentSession(jobId);
			
			/* Wait for files to be transferred */
			while (faspManagerListener.getFileTransferCount() != 1)
				Thread.sleep(100);
			
			FaspManager.destroy();
			System.out.println("Finished!");
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	static XferParams myTransferParams() {
		XferParams p = new XferParams();
		/* For most cases, these port numbers need not be changed */
		p.tcpPort = 22;
		p.udpPort = 33001;
		p.encryption = Encryption.NONE;
		p.policy = Policy.FAIR;
		p.cookie = "FaspManagerSample1-Cookie";
		// With newer versions of ascp if a token is passed it must be valid
		// regardles of whether or not username/password authentication is used
		// p.token = "FaspManagerSample1-Token";
		p.resumeCheck = Resume.OFF;
		p.preCalculateJobSize = true;
		/* Turn on persistence */
		p.persist = true;
		return p;
	}
}
