package samples.files;

/**
 * Created by mflathers on 6/14/16.
 */

import com.asperasoft.faspmanager.Encryption;
import com.asperasoft.faspmanager.FaspManager;
import com.asperasoft.faspmanager.LocalLocation;
import com.asperasoft.faspmanager.Policy;
import com.asperasoft.faspmanager.RemoteLocation;
import com.asperasoft.faspmanager.Resume;
import com.asperasoft.faspmanager.TransferOrder;
import com.asperasoft.faspmanager.XferParams;

import java.io.File;

class SimplePersistentS3Upload {

    public static void main(String[] args) throws Exception {
        try {
            FaspManagerListener faspManagerListener = new FaspManagerListener();
            FaspManager.getSingleton().addListener(faspManagerListener);

            RemoteLocation remoteDestination =
                    new RemoteLocation("s3.asperasoft.com", "xfer", "/Users/mflathers/.ssh/s3-demo-key", "");

            LocalLocation localSource = new LocalLocation();

			/* Note that we do not add any paths to the location objects */
			/* Setup a job order. */
            TransferOrder order =
                    new TransferOrder(localSource, remoteDestination,
                            myTransferParams());

			/* Start the persistent session */
            String jobId = FaspManager.getSingleton().startTransfer(order);

			/* Wait for the session to be started */
            while (!faspManagerListener.isSessionReady())
                Thread.sleep(100);

            File tsSegmentDir = new File("/Users/mflathers/Movies/ts-segments");
            if (tsSegmentDir != null && tsSegmentDir.isDirectory()) {
                File[] listOfFiles = tsSegmentDir.listFiles();

                int numFilesInDestDir = 0;
                int maxFilesInDir = 3;
                int dirNum = 0;
                for (int i = 0; i < listOfFiles.length; i++) {
                    if (listOfFiles[i].isDirectory()) {
                        System.out.println("Directory " + listOfFiles[i].getName());
                    }
                    else if (listOfFiles[i].isFile()) {
                        if (listOfFiles[i].getName().equalsIgnoreCase(".DS_Store") || listOfFiles[i].isDirectory()) {
                            continue;
                        }
                        String fullDest = "Dir" + dirNum + "/" + listOfFiles[i].getName();

                        System.out.println("File " + listOfFiles[i].getName() + " : " + fullDest);

                        FaspManager.getSingleton().addSource(jobId, listOfFiles[i].getAbsolutePath(), fullDest);
                        numFilesInDestDir++;
                        if (numFilesInDestDir >= maxFilesInDir) {
                            dirNum++;
                            numFilesInDestDir = 0;
                        }
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    static XferParams myTransferParams() {
        XferParams p = new XferParams();
		/* For most cases, these port numbers need not be changed */
        p.destinationRoot = "s3://AKIAJPRWDQ5BX7QTQKHQ:KScxFAW4SMOQSECZAqU1vZH4lgurfiFyd9aPHcm1@s3.amazonaws.com/aspera-demo/mike";
        p.tcpPort = 22;
        p.udpPort = 33001;
        p.encryption = Encryption.NONE;
        p.policy = Policy.FAIR;
        p.cookie = "FaspManagerSample1-Cookie";
        // With newer versions of ascp if a token is passed it must be valid
        // regardles of whether or not username/password authentication is used
        // p.token = "FaspManagerSample1-Token";
        p.resumeCheck = Resume.OFF;
        p.preCalculateJobSize = true;
		/* Turn on persistence */
        p.persist = true;
        p.createPath = true;
        p.targetRateKbps = 100000;
        return p;
    }
}
