package samples.files;

/*
 * A simple application that demonstrates the use of Aspera Java FASP Manager
 * API. Aspera, Inc.
 */

import com.asperasoft.faspmanager.Encryption;
import com.asperasoft.faspmanager.Environment;
import com.asperasoft.faspmanager.FaspManager;
import com.asperasoft.faspmanager.Policy;
import com.asperasoft.faspmanager.RemoteLocation;
import com.asperasoft.faspmanager.Resume;
import com.asperasoft.faspmanager.SerializedStreamException;
import com.asperasoft.faspmanager.StreamOrder;
import com.asperasoft.faspmanager.TransferOrder;
import com.asperasoft.faspmanager.XferParams;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;

class SimpleStreamUpload {

	public static void main(String[] args) throws Exception {
		try {
			/* If Fasp Manager does not automatically find ascp use this specify the path to ascp */
			// Environment.setFasp2ScpPath("C:\\Program Files (x86)\\Aspera\\Enterprise Server\\bin\\ascp.exe");

			// Specify the path to ascp4.
			Environment.setFasp2ScpPath("/Library/Aspera/bin/ascp4");

			FaspManagerListener faspManagerListener = new FaspManagerListener(true);
			FaspManager.getSingleton().addListener(faspManagerListener);

			RemoteLocation remoteDestination = new RemoteLocation("demo.asperasoft.com", "aspera", "demoaspera");

			/* Note that we do not add any paths to the location objects */
			/* Setup a job order. */
			TransferOrder order = new StreamOrder(remoteDestination, myTransferParams());

			/* Start the persistent session */
			String jobId = FaspManager.getSingleton().startTransfer(order);

			/* Wait for the session to be started */
			while (!faspManagerListener.isSessionReady())
				Thread.sleep(100);

			/* Add some streams for upload */

			// Add a standard Java InputStream with data from a file
            // for a stream-to-file upload
			FaspManager.getSingleton().addSource(jobId, new FileInputStream(new File("10MB.1")), "Upload/10MB.1");

            //Add a standard Java Reader with data from a TCP Socket
            // for a stream-to-file upload
			java.net.URL url = new java.net.URL("http://www.google.com");
			HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			InputStream inputStream = connection.getInputStream();

			while (true) {
				try {
					FaspManager.getSingleton().addSource(jobId, inputStream, "/Upload/google.html");
					break;
				}
				catch(SerializedStreamException e) {
				}
			}

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	static XferParams myTransferParams() {
		XferParams p = new XferParams();
		/* For most cases, these port numbers need not be changed */
		p.tcpPort = 22;
		p.udpPort = 33001;
		p.encryption = Encryption.NONE;
		p.policy = Policy.FAIR;
		p.cookie = "FaspManagerSample1-Cookie";
		// With newer versions of ascp if a token is passed it must be valid
		// regardles of whether or not username/password authentication is used
		// p.token = "FaspManagerSample1-Token";
		p.resumeCheck = Resume.OFF;
		p.preCalculateJobSize = true;
		return p;
	}
}
